declare enum BatteryHealth {
    UNKNOWN = 1,
    GOOD = 2,
    OVERHEAT = 3,
    DEAD = 4,
    OVER_VOLTAGE = 5,
    UNSPECIFIED_FAILURE = 6,
    COLD = 7
}
declare enum BatteryPlugged {
    DOCK = 0,
    AC = 1,
    USB = 2,
    WIRELESS = 4
}
declare enum BatteryStatus {
    UNKNOWN = 1,
    CHARGING = 2,
    DISCHARGING = 3,
    NOT_CHARGING = 4,
    FULL = 5
}
declare class Battery {
    health?: BatteryHealth | undefined;
    plugged?: BatteryPlugged | undefined;
    status?: BatteryStatus | undefined;
    capacity?: number | undefined;
    /**
     *  Class representing the device's battery health, status and plugged state.
     *  See https://developer.android.com/reference/android/os/BatteryManager for more information.
     * @param health the battery's health (either UNKNOWN, GOOD, OVERHEAT, DEAD, OVER_VOLTAGE, UNSPECIFIED_FAILURE, COLD)
     * @param plugged the battery's plugged status (either DOCK, AC, USB, WIRELESS)
     * @param status the battery's status (either UNKNOWN, CHARGING, DISCHARGING, NOT_CHARGING, FULL)
     * @param capacity Remaining battery capacity as an integer percentage of total capacity (with no fractional part).
     */
    constructor(health?: BatteryHealth | undefined, plugged?: BatteryPlugged | undefined, status?: BatteryStatus | undefined, capacity?: number | undefined);
    /**
     * Create from JSON
     * @param battery JSON object
     */
    static fromJSON(battery: any): Battery;
}
export { BatteryHealth, BatteryPlugged, BatteryStatus, Battery };
