"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Battery = exports.BatteryStatus = exports.BatteryPlugged = exports.BatteryHealth = void 0;
var BatteryHealth;
(function (BatteryHealth) {
    BatteryHealth[BatteryHealth["UNKNOWN"] = 1] = "UNKNOWN";
    BatteryHealth[BatteryHealth["GOOD"] = 2] = "GOOD";
    BatteryHealth[BatteryHealth["OVERHEAT"] = 3] = "OVERHEAT";
    BatteryHealth[BatteryHealth["DEAD"] = 4] = "DEAD";
    BatteryHealth[BatteryHealth["OVER_VOLTAGE"] = 5] = "OVER_VOLTAGE";
    BatteryHealth[BatteryHealth["UNSPECIFIED_FAILURE"] = 6] = "UNSPECIFIED_FAILURE";
    BatteryHealth[BatteryHealth["COLD"] = 7] = "COLD";
})(BatteryHealth || (BatteryHealth = {}));
exports.BatteryHealth = BatteryHealth;
var BatteryPlugged;
(function (BatteryPlugged) {
    BatteryPlugged[BatteryPlugged["DOCK"] = 0] = "DOCK";
    BatteryPlugged[BatteryPlugged["AC"] = 1] = "AC";
    BatteryPlugged[BatteryPlugged["USB"] = 2] = "USB";
    BatteryPlugged[BatteryPlugged["WIRELESS"] = 4] = "WIRELESS";
})(BatteryPlugged || (BatteryPlugged = {}));
exports.BatteryPlugged = BatteryPlugged;
var BatteryStatus;
(function (BatteryStatus) {
    BatteryStatus[BatteryStatus["UNKNOWN"] = 1] = "UNKNOWN";
    BatteryStatus[BatteryStatus["CHARGING"] = 2] = "CHARGING";
    BatteryStatus[BatteryStatus["DISCHARGING"] = 3] = "DISCHARGING";
    BatteryStatus[BatteryStatus["NOT_CHARGING"] = 4] = "NOT_CHARGING";
    BatteryStatus[BatteryStatus["FULL"] = 5] = "FULL";
})(BatteryStatus || (BatteryStatus = {}));
exports.BatteryStatus = BatteryStatus;
class Battery {
    /**
     *  Class representing the device's battery health, status and plugged state.
     *  See https://developer.android.com/reference/android/os/BatteryManager for more information.
     * @param health the battery's health (either UNKNOWN, GOOD, OVERHEAT, DEAD, OVER_VOLTAGE, UNSPECIFIED_FAILURE, COLD)
     * @param plugged the battery's plugged status (either DOCK, AC, USB, WIRELESS)
     * @param status the battery's status (either UNKNOWN, CHARGING, DISCHARGING, NOT_CHARGING, FULL)
     * @param capacity Remaining battery capacity as an integer percentage of total capacity (with no fractional part).
     */
    constructor(health, plugged, status, capacity) {
        this.health = health;
        this.plugged = plugged;
        this.status = status;
        this.capacity = capacity;
    }
    /**
     * Create from JSON
     * @param battery JSON object
     */
    static fromJSON(battery) {
        return new Battery(battery.health, battery.plugged, battery.status, battery.capacity);
    }
}
exports.Battery = Battery;
//# sourceMappingURL=Battery.js.map